@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 The jdeb developers.
+ * Copyright 2016 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,10 +25,10 @@ import java.io.InputStream;
  */
 public interface DataConsumer {
 
-    void onEachDir( String dirname, String linkname, String user, int uid, String group, int gid, int mode, long size ) throws IOException;
+    void onEachDir( TarArchiveEntry dirEntry ) throws IOException;
 
-    void onEachFile( InputStream input, TarArchiveEntry entry ) throws IOException;
+    void onEachFile( InputStream input, TarArchiveEntry fileEntry ) throws IOException;
 
-    void onEachLink( TarArchiveEntry entry ) throws IOException;
+    void onEachLink( TarArchiveEntry linkEntry ) throws IOException;
 
 }
