@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 The jdeb developers.
+ * Copyright 2016 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@
 package org.vafer.jdeb.maven;
 
 import static org.vafer.jdeb.utils.Utils.lookupIfEmpty;
+import static org.vafer.jdeb.utils.Utils.isBlank;
 
 import java.io.File;
 import java.io.FileInputStream;
@@ -45,7 +46,6 @@ import org.apache.maven.project.MavenProjectHelper;
 import org.apache.maven.settings.Profile;
 import org.apache.maven.settings.Settings;
 import org.apache.tools.tar.TarEntry;
-import org.codehaus.plexus.util.StringUtils;
 import org.sonatype.plexus.components.sec.dispatcher.SecDispatcher;
 import org.sonatype.plexus.components.sec.dispatcher.SecDispatcherException;
 import org.vafer.jdeb.Console;
@@ -147,7 +147,7 @@ public class DebMojo extends AbstractMojo {
      */
     @Parameter( defaultValue = "${session}", readonly = true )
     private MavenSession session;
-    
+
     /**
      * The Maven Project Object
      */
@@ -166,13 +166,21 @@ public class DebMojo extends AbstractMojo {
     @Parameter
     private String classifier;
 
+    /**
+     * The digest algorithm to use.
+     *
+     * @see org.bouncycastle.bcpg.HashAlgorithmTags
+     */
+    @Parameter(defaultValue = "SHA1")
+    private String digest;
+
     /**
      * "data" entries used to determine which files should be added to this deb.
      * The "data" entries may specify a tarball (tar.gz, tar.bz2, tgz), a
      * directory, or a normal file. An entry would look something like this in
      * your pom.xml:
-     * 
-     * 
+     *
+     *
      * <pre>
      *   <build>
      *     <plugins>
@@ -219,7 +227,7 @@ public class DebMojo extends AbstractMojo {
      *     </plugins>
      *   </build>
      * </pre>
-     * 
+     *
      */
     @Parameter
     private Data[] dataSet;
@@ -252,7 +260,7 @@ public class DebMojo extends AbstractMojo {
 
     /**
      * Indicates if the execution should be disabled. If <code>true</code>, nothing will occur during execution.
-     * 
+     *
      * @since 1.1
      */
     @Parameter(defaultValue = "false")
@@ -263,7 +271,7 @@ public class DebMojo extends AbstractMojo {
 
     @Parameter(defaultValue = "false")
     private boolean skipSubmodules;
-    
+
     /**
      * @deprecated
      */
@@ -277,7 +285,13 @@ public class DebMojo extends AbstractMojo {
      */
     @Parameter(defaultValue = "false")
     private boolean signPackage;
-    
+
+    /**
+     * If signChanges is true then changes file will be signed.
+     */
+    @Parameter(defaultValue = "false")
+    private boolean signChanges;
+
     /**
      * Defines which utility is used to verify the signed package
      */
@@ -289,7 +303,7 @@ public class DebMojo extends AbstractMojo {
      */
     @Parameter(defaultValue = "origin")
     private String signRole;
-    
+
     /**
      * The keyring to use for signing operations.
      */
@@ -306,7 +320,7 @@ public class DebMojo extends AbstractMojo {
      * The passphrase to use for signing operations.
      */
     @Parameter
-    private String passphrase; 
+    private String passphrase;
 
     /**
      * The prefix to use when reading signing variables
@@ -320,12 +334,12 @@ public class DebMojo extends AbstractMojo {
      */
     @Parameter(defaultValue = "${settings}")
     private Settings settings;
-    
+
     @Parameter(defaultValue = "")
     private String propertyPrefix;
 
     /* end of parameters */
-    
+
     private static final String KEY = "key";
     private static final String KEYRING = "keyring";
     private static final String PASSPHRASE = "passphrase";
@@ -350,7 +364,7 @@ public class DebMojo extends AbstractMojo {
         conffileProducers.clear();
         if (dataSet != null) {
             Collections.addAll(dataProducers, dataSet);
-            
+
             for (Data item : dataSet) {
                 if (item.getConffile()) {
                     conffileProducers.add(item);
@@ -493,7 +507,6 @@ public class DebMojo extends AbstractMojo {
                     final File file = artifact.getFile();
                     if (file != null) {
                         dataProducers.add(new DataProducer() {
-                            @Override
                             public void produce( final DataConsumer receiver ) {
                                 try {
                                     final File path = new File(installDirFile.getPath(), file.getName());
@@ -543,11 +556,13 @@ public class DebMojo extends AbstractMojo {
             debMaker.setKey(key);
             debMaker.setPassphrase(passphrase);
             debMaker.setSignPackage(signPackage);
+            debMaker.setSignChanges(signChanges);
             debMaker.setSignMethod(signMethod);
             debMaker.setSignRole(signRole);
             debMaker.setResolver(resolver);
             debMaker.setOpenReplaceToken(openReplaceToken);
             debMaker.setCloseReplaceToken(closeReplaceToken);
+            debMaker.setDigest(digest);
             debMaker.validate();
             debMaker.makeDeb();
 
@@ -565,8 +580,8 @@ public class DebMojo extends AbstractMojo {
             getLog().error("Failed to create debian package " + debFile, e);
             throw new MojoExecutionException("Failed to create debian package " + debFile, e);
         }
-        
-        if (!StringUtils.isBlank(propertyPrefix)) {
+
+        if (!isBlank(propertyPrefix)) {
           project.getProperties().put(propertyPrefix+"version", getProjectVersion() );
           project.getProperties().put(propertyPrefix+"deb", debFile.getAbsolutePath());
           project.getProperties().put(propertyPrefix+"deb.name", debFile.getName());
@@ -575,7 +590,7 @@ public class DebMojo extends AbstractMojo {
           project.getProperties().put(propertyPrefix+"changes.txt", changesSaveFile.getAbsolutePath());
           project.getProperties().put(propertyPrefix+"changes.txt.name", changesSaveFile.getName());
         }
-        
+
     }
 
     /**
@@ -583,7 +598,7 @@ public class DebMojo extends AbstractMojo {
      * and global settings.
      */
     private void initializeSignProperties() {
-        if (!signPackage) {
+        if (!signPackage && !signChanges) {
             return;
         }
 
@@ -634,9 +649,9 @@ public class DebMojo extends AbstractMojo {
 
         return maybeEncryptedPassphrase;
     }
-    
+
     /**
-     * 
+     *
      * @return the maven project used by this mojo
      */
     private MavenProject getProject() {
